@@ -2,11 +2,21 @@ import React, { PropTypes } from 'react';
 import FormLabel from '../../components/style/form-label';
 import FormNumberInput from '../../components/style/form-number-input';
 
-export default function PropertyString(_ref) {
+export default function PropertyNumber(_ref) {
   var value = _ref.value,
       onUpdate = _ref.onUpdate,
       configs = _ref.configs;
 
+
+  var update = function update(value) {
+    var number = parseFloat(value);
+
+    if (isNaN(number)) {
+      number = 0;
+    }
+    return onUpdate(number);
+  };
+
   return React.createElement(
     'div',
     { style: { marginBottom: "3px" } },
@@ -23,14 +33,14 @@ export default function PropertyString(_ref) {
       'div',
       { style: { display: "inline-block", width: "70%" } },
       React.createElement(FormNumberInput, { value: value, onChange: function onChange(event) {
-          return onUpdate(parseFloat(event.target.value));
+          return update(event.target.value);
         },
         min: configs.min, max: configs.max })
     )
   );
 }
 
-PropertyString.propTypes = {
+PropertyNumber.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired
