@@ -2,7 +2,17 @@ import React, {PropTypes} from 'react';
 import FormLabel from '../../components/style/form-label'
 import FormNumberInput from '../../components/style/form-number-input';
 
-export default function PropertyString({value, onUpdate, configs}) {
+export default function PropertyNumber({value, onUpdate, configs}) {
+
+  let update = (value) => {
+    let number = parseFloat(value);
+
+    if (isNaN(number)) {
+      number = 0;
+    }
+    return onUpdate(number);
+  };
+
   return (
     <div style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
@@ -10,7 +20,7 @@ export default function PropertyString({value, onUpdate, configs}) {
       </div>
 
       <div style={{display: "inline-block", width: "70%"}}>
-        <FormNumberInput value={value} onChange={event => onUpdate(parseFloat(event.target.value))}
+        <FormNumberInput value={value} onChange={event => update(event.target.value)}
                          min={configs.min} max={configs.max}/>
       </div>
 
@@ -19,7 +29,7 @@ export default function PropertyString({value, onUpdate, configs}) {
 
 }
 
-PropertyString.propTypes = {
+PropertyNumber.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired
