@@ -18,7 +18,7 @@ const STYLE_CIRCLE2 = {
   cursor: "ew-resize"
 };
 
-export default function Item({layer, item, scene}, {catalog}) {
+export default function Item({layer, item, scene, catalog}) {
 
   let {x, y, rotation} = item;
 
@@ -54,12 +54,7 @@ export default function Item({layer, item, scene}, {catalog}) {
 Item.propTypes = {
   item: PropTypes.object.isRequired,
   layer: PropTypes.object.isRequired,
-  mode: PropTypes.string.isRequired,
   scene: PropTypes.object.isRequired,
+  catalog: PropTypes.object.isRequired
 };
 
-
-Item.contextTypes = {
-  editingActions: PropTypes.object,
-  catalog: React.PropTypes.object
-};
